@@ -63,6 +63,7 @@ from .. import tools
 
 from . import init
 from . import wrap_main
+from . import validate_client_customs
 from . import get_configured_log
 from . import get_configured_client
 from . import get_configured_trackers
@@ -129,7 +130,6 @@ class Feeder:  # pylint: disable=too-many-instance-attributes
         show_passed: bool,
         show_diff: bool,
         log_stdout: Log,
-        log_stderr: Log,
     ) -> None:
 
         self._trackers = trackers
@@ -138,7 +138,6 @@ class Feeder:  # pylint: disable=too-many-instance-attributes
         self._show_passed = show_passed
         self._show_diff = show_diff
         self._log_stdout = log_stdout
-        self._log_stderr = log_stderr
 
         self._current_count = 0
         self._current_file_name = ""
@@ -216,7 +215,7 @@ class Feeder:  # pylint: disable=too-many-instance-attributes
 
     def _done_affected(self, result: UpdateResult) -> None:
         self._log_stdout.print(*self._format_status("green", "+"))
-        if self._show_diff:
+        if self._show_diff and result.diff:
             self._log_stdout.print(*fmt.format_torrents_diff(result.diff, "\t"))
 
     def _done_not_in_client(self, _: Any) -> None:
@@ -262,7 +261,7 @@ class Feeder:  # pylint: disable=too-many-instance-attributes
         return (
             "[{" + color + "}%s{reset}] " + progress + " {" + color + "}%s {cyan}%s{reset} -- %s",
             (
-                sign, *placeholders, self._current_tracker.PLUGIN_NAME,
+                sign, *placeholders, self._current_tracker.PLUGIN_NAMES[0],
                 self._current_file_name, self._current_torrent.get_comment(),
             ),
         )
@@ -424,6 +423,8 @@ def main() -> None:
     args_parser.add_argument("-f", "--name-filter", default="", metavar="<wildcard_pattern>")
     args_parser.add_argument("-y", "--only-trackers", default=[], nargs="+", metavar="<tracker>")
     args_parser.add_argument("-x", "--exclude-trackers", default=[], nargs="+", metavar="<tracker>")
+    args_parser.add_argument("--only-confetti", default=[], nargs="+", metavar="<tracker>")
+    args_parser.add_argument("--exclude-confetti", default=[], nargs="+", metavar="<tracker>")
     args_parser.add_argument("--noop", action="store_true")
     args_parser.add_argument("--mute", action="store_true")
     args_parser.add_argument("--fail-on-captcha", action="store_true")
@@ -439,25 +440,32 @@ def main() -> None:
                 with_customs=bool(len(config.emupdate.save_customs) or len(config.emupdate.set_customs)),
                 log=log_stderr,
             )
+            if client and config.emupdate.save_customs:
+                validate_client_customs(client, list(config.emupdate.save_customs))  # type: ignore
+            if client and config.emupdate.set_customs:
+                validate_client_customs(client, list(config.emupdate.set_customs))  # type: ignore
 
             def read_captcha(url: str) -> str:
                 if options.fail_on_captcha:
                     raise RuntimeError("Required decoding of captcha but '--fail-on-captcha' specified")
-                else:
-                    log_stderr.info("{yellow}Enter the captcha{reset} from [{blue}%s{reset}]: ", (url,), no_nl=True)
-                    return input()
+                log_stderr.info("{yellow}Enter the captcha{reset} from [{blue}%s{reset}]: ", (url,), no_nl=True)
+                return input()
 
             trackers = get_configured_trackers(
                 config=config,
                 captcha_decoder=read_captcha,
                 only=options.only_trackers,
                 exclude=options.exclude_trackers,
+                required_bases=[],
+                fail_bad_tracker=config.emupdate.fail_bad_tracker,
                 log=log_stderr,
             )
 
             if not options.mute:
                 confetti = get_configured_confetti(
                     config=config,
+                    only=options.only_confetti,
+                    exclude=options.exclude_confetti,
                     log=log_stderr,
                 )
 
@@ -475,7 +483,6 @@ def main() -> None:
                 show_passed=config.emupdate.show_passed,
                 show_diff=config.emupdate.show_diff,
                 log_stdout=log_stdout,
-                log_stderr=log_stderr,
             )
 
             update(
@@ -495,14 +502,13 @@ def main() -> None:
                 log=log_stderr,
             )
             if not options.mute:
-                if len(results["affected"]) != 0:
-                    if not surprise.deploy_surprise(
-                        source="emupdate",
-                        results=results,
-                        confetti=confetti,
-                        log=log_stderr,
-                    ):
-                        raise SystemExit(1)
+                if not surprise.deploy_surprise(
+                    source="emupdate",
+                    results=results,
+                    confetti=confetti,
+                    log=log_stderr,
+                ):
+                    raise SystemExit(1)
 
 
 if __name__ == "__main__":
