@@ -65,9 +65,9 @@ def build_files(prefix: str, flist: List[Tuple[str, int]]) -> Dict[str, TorrentE
         name = None
         for index in range(len(path_list)):
             name = os.path.join(prefix, os.path.sep.join(path_list[0:index + 1]))
-            files[name] = TorrentEntryAttrs.new_dir()
+            files[name] = TorrentEntryAttrs.dir()
         assert name is not None
-        files[name] = TorrentEntryAttrs.new_file(size)
+        files[name] = TorrentEntryAttrs.file(size)
     return files
 
 
@@ -76,22 +76,26 @@ class BaseClient(BasePlugin):
         pass
 
     @hash_or_torrent
-    def remove_torrent(self, torrent_hash: str) -> None:
+    def start_torrent(self, torrent_hash: str) -> None:
+        raise NotImplementedError
+
+    @hash_or_torrent
+    def stop_torrent(self, torrent_hash: str) -> None:
         raise NotImplementedError
 
     @check_torrent_accessible
-    def load_torrent(self, torrent: Torrent, prefix: str="") -> None:
+    def load_torrent(self, torrent: Torrent, prefix: str) -> None:
         raise NotImplementedError
 
-    def get_hashes(self) -> List[str]:
+    @hash_or_torrent
+    def remove_torrent(self, torrent_hash: str) -> None:
         raise NotImplementedError
 
     @hash_or_torrent
     def has_torrent(self, torrent_hash: str) -> bool:
         raise NotImplementedError
 
-    @hash_or_torrent
-    def get_torrent_path(self, torrent_hash: str) -> str:
+    def get_hashes(self) -> List[str]:
         raise NotImplementedError
 
     @hash_or_torrent
@@ -101,7 +105,7 @@ class BaseClient(BasePlugin):
     def get_data_prefix_default(self) -> str:
         raise NotImplementedError
 
-    # ===
+    # =====
 
     @hash_or_torrent
     def get_full_path(self, torrent_hash: str) -> str:
@@ -112,11 +116,7 @@ class BaseClient(BasePlugin):
         raise NotImplementedError
 
     @hash_or_torrent
-    def is_single_file(self, torrent_hash: str) -> bool:
-        raise NotImplementedError
-
-    @hash_or_torrent
-    def get_files(self, torrent_hash: str, on_fs: bool=False) -> Dict[str, TorrentEntryAttrs]:
+    def get_files(self, torrent_hash: str) -> Dict[str, TorrentEntryAttrs]:
         raise NotImplementedError
 
 
